This is a package with playrobot product.

Include RBB, PiBB and Intellgent Robot

Lib has following functions:

STT:

stt():sound to text,return a string

setProperty(chunk = 1024,rate = 16000,rec = 5):change record property

TTS:

wordToSound(string):speech a string which you want to speak
